'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// functions
const asArray = (input, index) => input[index < 0 ? input.length + index : index];
const asObject = (input, key) => input[key];
/**
 * Get the value at the specified index or key.
 * @param input - The input.
 * @param key - The index or key.
 * @returns The value at the specified index or key.
 * @example
 * ```
 * const array = [1, 2, 3]
 * console.log(at(array, 1))
 * //=> 2
 * console.log(at(array, -1))
 * //=> 3
 * console.log(at(array, 3))
 * //=> undefined
 *
 * const object = { a: 1, b: 2, c: 3 }
 * console.log(at(object, 'b'))
 * //=> 2
 * console.log(at(object, 'd'))
 * //=> undefined
 * ```
 */
const at = (input, key) => {
    if (Array.isArray(input))
        return asArray(input, key);
    return asObject(input, key);
};

exports.default = at;
