'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fse = require('fs-extra');
var echo = require('./echo.js');
var getBasename = require('./getBasename.js');
var getDirname = require('./getDirname.js');
var getExtname = require('./getExtname.js');
var getFilename = require('./getFilename.js');
var glob = require('./glob.js');
var isAsyncFunction = require('./isAsyncFunction.js');
var normalizePath = require('./normalizePath.js');
var wrapList = require('./wrapList.js');
var run = require('./run.js');
require('kleur');
require('./home.js');
require('os');
require('./root.js');
require('./toString.js');
require('./getType.js');
require('./getName.js');
require('path');
require('fast-glob');
require('./toArray.js');
require('./isFunction.js');
require('./trimEnd-BzcVuRxk.js');

// function
/**
 * Copy files or directories.
 * @param source A source file or directory.
 * @param target A target directory.
 * @param name A new name.
 * @returns The promise.
 * @example
 * ```
 * await copy('file.txt')
 * await copy(['file1.txt', 'file2.txt'])
 * await copy('file.txt', 'backup')
 * await copy('file.txt', 'backup', 'file.bak')
 * await copy('file.txt', name => `backup/${name}`)
 * ```
 */
const copy = async (source, target, name) => {
    const listSource = await glob.default(source);
    for (const src of listSource) {
        const dirname = await run.default(() => {
            const dname = getDirname.default(src);
            if (!target)
                return dname;
            if (typeof target === 'function')
                return execute(target, dname);
            return target;
        });
        const filename = await run.default(() => {
            const fname = getFilename.default(src);
            if (!name)
                return dirname === getDirname.default(src)
                    ? `${getBasename.default(src)}.copy${getExtname.default(src)}`
                    : fname;
            if (typeof name === 'function')
                return execute(name, fname);
            return name;
        });
        await fse.copy(src, normalizePath.default(`${dirname}/${filename}`));
    }
    echo.default('file', [
        `copied ${wrapList.default(source)}`,
        target && typeof target === 'string' ? ` to '${target}'` : '',
        name && typeof name === 'string' ? ` as '${name}'` : '',
    ]
        .filter(it => !!it)
        .join(''));
};
const execute = (fn, input) => {
    if (isAsyncFunction.default(fn))
        return fn(input);
    return fn(input);
};

exports.default = copy;
