type Input = string | ((input: string) => string | Promise<string>);
/**
 * Copy files or directories.
 * @param source A source file or directory.
 * @param target A target directory.
 * @param name A new name.
 * @returns The promise.
 * @example
 * ```
 * await copy('file.txt')
 * await copy(['file1.txt', 'file2.txt'])
 * await copy('file.txt', 'backup')
 * await copy('file.txt', 'backup', 'file.bak')
 * await copy('file.txt', name => `backup/${name}`)
 * ```
 */
declare const copy: (source: string | string[], target?: Input, name?: Input) => Promise<void>;
export { copy as default };
