import fse from 'fs-extra';
import echo from './echo.js';
import getBasename from './getBasename.js';
import getDirname from './getDirname.js';
import getExtname from './getExtname.js';
import getFilename from './getFilename.js';
import main from './glob.js';
import isAsyncFunction from './isAsyncFunction.js';
import normalizePath from './normalizePath.js';
import wrapList from './wrapList.js';
import run from './run.js';
import 'kleur';
import './home.js';
import 'os';
import './root.js';
import './toString.js';
import './getType.js';
import './getName.js';
import 'path';
import 'fast-glob';
import './toArray.js';
import './isFunction.js';
import './trimEnd-DGu8GQJm.js';

// function
/**
 * Copy files or directories.
 * @param source A source file or directory.
 * @param target A target directory.
 * @param name A new name.
 * @returns The promise.
 * @example
 * ```
 * await copy('file.txt')
 * await copy(['file1.txt', 'file2.txt'])
 * await copy('file.txt', 'backup')
 * await copy('file.txt', 'backup', 'file.bak')
 * await copy('file.txt', name => `backup/${name}`)
 * ```
 */
const copy = async (source, target, name) => {
    const listSource = await main(source);
    for (const src of listSource) {
        const dirname = await run(() => {
            const dname = getDirname(src);
            if (!target)
                return dname;
            if (typeof target === 'function')
                return execute(target, dname);
            return target;
        });
        const filename = await run(() => {
            const fname = getFilename(src);
            if (!name)
                return dirname === getDirname(src)
                    ? `${getBasename(src)}.copy${getExtname(src)}`
                    : fname;
            if (typeof name === 'function')
                return execute(name, fname);
            return name;
        });
        await fse.copy(src, normalizePath(`${dirname}/${filename}`));
    }
    echo('file', [
        `copied ${wrapList(source)}`,
        target && typeof target === 'string' ? ` to '${target}'` : '',
        name && typeof name === 'string' ? ` as '${name}'` : '',
    ]
        .filter(it => !!it)
        .join(''));
};
const execute = (fn, input) => {
    if (isAsyncFunction(fn))
        return fn(input);
    return fn(input);
};

export { copy as default };
