import child from 'child_process';
import kleur from 'kleur';
import { t as trimEnd } from './trimEnd-DGu8GQJm.js';
import echo from './echo.js';
import os from './os.js';
import './home.js';
import 'os';
import './root.js';
import './toString.js';
import './getType.js';

// variable
const separator = os() === 'windows' ? ' && ' : '; ';
// functions
/**
 * Execute the command.
 * @param cmd The command.
 * @param option The option.
 * @returns The result.
 * @example
 * ```
 * const [code, last, all] = await exec('echo "Hello, world!"')
 * ```
 */
const exec = (cmd, option = {}) => {
    const stringCmd = cmd instanceof Array ? cmd.join(separator) : cmd;
    const [cmder, arg] = os() === 'windows'
        ? ['cmd.exe', ['/s', '/c', stringCmd]]
        : ['/bin/sh', ['-c', stringCmd]];
    if (!option.silent)
        echo('exec', stringCmd);
    return new Promise(resolve => {
        const cacheAll = [];
        let cacheLast = '';
        const process = child.spawn(cmder, arg, {});
        process.stderr.on('data', (data) => {
            const message = parseMessage(data);
            cacheAll.push(message);
            cacheLast = message;
            if (!option.silent)
                info('error', message);
        });
        process.stdout.on('data', (data) => {
            const message = parseMessage(data);
            cacheAll.push(message);
            cacheLast = message;
            if (!option.silent)
                info('default', message);
        });
        process.on('close', (code) => resolve([code, cacheLast, cacheAll]));
    });
};
const info = (type, message) => {
    if (!message)
        return;
    console.log(type === 'error' ? kleur.red(message) : kleur.gray(message));
};
const parseMessage = (buffer) => trimEnd(buffer.toString().trim(), '\n')
    .replace(/\r/g, '\n')
    .replace(/\n{2,}/g, '');

export { exec as default };
