import isFunction from './isFunction.js';

// function
/**
 * Check if the input is an async function.
 *
 * @param input The value to check.
 * @returns Returns the result of the check.
 * @example
 * ```
 * const isAsync = isAsyncFunction(async () => {})
 * //=> true
 * ```
 */
const isAsyncFunction = (input) => {
    if (!isFunction(input))
        return false;
    const type = Object.prototype.toString
        .call(input)
        .replace(/^\[object (.+)\]$/, '$1')
        .toLowerCase();
    return type === 'asyncfunction';
};

export { isAsyncFunction as default };
