import { f as flatten } from './isExist-CPc5sQmt.js';
import echo from './echo.js';
import normalizePath from './normalizePath.js';
import read from './read.js';
import stat from './stat.js';
import toString from './toString.js';
import 'fs-extra';
import './trimEnd-DGu8GQJm.js';
import './isArguments-QSN3fPWr.js';
import 'kleur';
import './home.js';
import 'os';
import './root.js';
import './getType.js';
import 'path';
import 'fs';
import './getExtname.js';
import './getName.js';
import './glob.js';
import 'fast-glob';
import './toArray.js';
import './toJSON.js';
import 'lodash';
import './isArray.js';
import './wrapList.js';

// function
/**
 * Check if the content of the paths are the same.
 * @param args The paths.
 * @returns `true` if the content of the paths are the same, or `false` otherwise.
 * @example
 * ```
 * await isSame('file1.txt', 'file2.txt')
 * ```
 */
const isSame = async (...args) => {
    const group = flatten(args).map(normalizePath);
    if (group.length < 2)
        return false;
    // size
    let cacheSize = 0;
    for (const source of group) {
        const stats = await stat(source);
        if (!stats)
            return false;
        const { size } = stats;
        if (!cacheSize) {
            cacheSize = size;
            continue;
        }
        if (size !== cacheSize)
            return false;
    }
    // content
    let cacheCont = '';
    for (const source of group) {
        let cont = await echo.whisper(read(source));
        if (!cont)
            return false;
        cont = toString(cont);
        if (!cacheCont) {
            cacheCont = cont;
            continue;
        }
        if (cont !== cacheCont)
            return false;
    }
    return true;
};

export { isSame as default };
