import fs from 'fs';
import echo from './echo.js';
import getExtname from './getExtname.js';
import main from './glob.js';
import toJSON from './toJSON.js';
import toString from './toString.js';
import 'kleur';
import './home.js';
import 'os';
import './root.js';
import './getType.js';
import './getName.js';
import 'path';
import 'fast-glob';
import './normalizePath.js';
import './trimEnd-DGu8GQJm.js';
import './toArray.js';
import 'lodash';
import './isArray.js';

// variable
const listExtString = [
    '.coffee',
    '.css',
    '.html',
    '.js',
    '.md',
    '.pug',
    '.sh',
    '.styl',
    '.ts',
    '.tsx',
    '.txt',
    '.xml',
];
// function
/**
 * Read a file.
 * @param source The source file.
 * @param option The option.
 * @returns The promise.
 * @example
 * ```
 * const content = await read('file.txt')
 * ```
 */
const read = async (source, option) => {
    let src = source;
    const listSource = await main(src);
    if (!listSource.length) {
        echo('file', `'${source}' not existed`);
        return undefined;
    }
    src = listSource[0];
    const content = await new Promise(resolve => {
        fs.readFile(src, (err, data) => {
            if (err)
                throw err;
            resolve(data);
        });
    });
    echo('file', `read '${source}'`);
    if (option?.raw)
        return content;
    const extname = getExtname(src);
    if (listExtString.includes(extname))
        return toString(content);
    if (extname === '.json')
        return toJSON(content);
    if (['.yaml', '.yml'].includes(extname)) {
        const jsYaml = (await import('js-yaml')).default;
        return jsYaml.load(content.toString());
    }
    return content;
};

export { read as default };
