import { isObject } from 'lodash';
import getType from './getType.js';
import isArray from './isArray.js';

// function
/**
 * Convert input to JSON.
 * @param input Input to convert.
 * @returns The JSON.
 * @example
 * ```
 * const json = toJson('{"key": "value"}')
 * console.log(json)
 * //=> { key: 'value' }
 * ```
 */
const toJSON = (input) => {
    if (typeof input === 'string')
        return JSON.parse(input);
    if (isArray(input))
        return input;
    if (input instanceof Uint8Array)
        return JSON.parse(input.toString());
    if (isObject(input))
        return input;
    throw new Error(`toJSON/error: invalid type '${getType(input)}'`);
};

export { toJSON as default };
