'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var child = require('child_process');
var kleur = require('kleur');
var trimEnd = require('./trimEnd-BzcVuRxk.js');
var echo = require('./echo.js');
var os = require('./os.js');
require('./home.js');
require('os');
require('./root.js');
require('./toString.js');
require('./getType.js');

// variable
const separator = os.default() === 'windows' ? ' && ' : '; ';
// functions
/**
 * Execute the command.
 * @param cmd The command.
 * @param option The option.
 * @returns The result.
 * @example
 * ```
 * const [code, last, all] = await exec('echo "Hello, world!"')
 * ```
 */
const exec = (cmd, option = {}) => {
    const stringCmd = cmd instanceof Array ? cmd.join(separator) : cmd;
    const [cmder, arg] = os.default() === 'windows'
        ? ['cmd.exe', ['/s', '/c', stringCmd]]
        : ['/bin/sh', ['-c', stringCmd]];
    if (!option.silent)
        echo.default('exec', stringCmd);
    return new Promise(resolve => {
        const cacheAll = [];
        let cacheLast = '';
        const process = child.spawn(cmder, arg, {});
        process.stderr.on('data', (data) => {
            const message = parseMessage(data);
            cacheAll.push(message);
            cacheLast = message;
            if (!option.silent)
                info('error', message);
        });
        process.stdout.on('data', (data) => {
            const message = parseMessage(data);
            cacheAll.push(message);
            cacheLast = message;
            if (!option.silent)
                info('default', message);
        });
        process.on('close', (code) => resolve([code, cacheLast, cacheAll]));
    });
};
const info = (type, message) => {
    if (!message)
        return;
    console.log(type === 'error' ? kleur.red(message) : kleur.gray(message));
};
const parseMessage = (buffer) => trimEnd.trimEnd(buffer.toString().trim(), '\n')
    .replace(/\r/g, '\n')
    .replace(/\n{2,}/g, '');

exports.default = exec;
