'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fs = require('fs');
var echo = require('./echo.js');
var getExtname = require('./getExtname.js');
var glob = require('./glob.js');
var toJSON = require('./toJSON.js');
var toString = require('./toString.js');
require('kleur');
require('./home.js');
require('os');
require('./root.js');
require('./getType.js');
require('./getName.js');
require('path');
require('fast-glob');
require('./normalizePath.js');
require('./trimEnd-BzcVuRxk.js');
require('./toArray.js');
require('lodash');
require('./isArray.js');

// variable
const listExtString = [
    '.coffee',
    '.css',
    '.html',
    '.js',
    '.md',
    '.pug',
    '.sh',
    '.styl',
    '.ts',
    '.tsx',
    '.txt',
    '.xml',
];
// function
/**
 * Read a file.
 * @param source The source file.
 * @param option The option.
 * @returns The promise.
 * @example
 * ```
 * const content = await read('file.txt')
 * ```
 */
const read = async (source, option) => {
    let src = source;
    const listSource = await glob.default(src);
    if (!listSource.length) {
        echo.default('file', `'${source}' not existed`);
        return undefined;
    }
    src = listSource[0];
    const content = await new Promise(resolve => {
        fs.readFile(src, (err, data) => {
            if (err)
                throw err;
            resolve(data);
        });
    });
    echo.default('file', `read '${source}'`);
    if (option?.raw)
        return content;
    const extname = getExtname.default(src);
    if (listExtString.includes(extname))
        return toString.default(content);
    if (extname === '.json')
        return toJSON.default(content);
    if (['.yaml', '.yml'].includes(extname)) {
        const jsYaml = (await import('js-yaml')).default;
        return jsYaml.load(content.toString());
    }
    return content;
};

exports.default = read;
