'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var lodash = require('lodash');
var getType = require('./getType.js');
var isArray = require('./isArray.js');

// function
/**
 * Convert input to JSON.
 * @param input Input to convert.
 * @returns The JSON.
 * @example
 * ```
 * const json = toJson('{"key": "value"}')
 * console.log(json)
 * //=> { key: 'value' }
 * ```
 */
const toJSON = (input) => {
    if (typeof input === 'string')
        return JSON.parse(input);
    if (isArray.default(input))
        return input;
    if (input instanceof Uint8Array)
        return JSON.parse(input.toString());
    if (lodash.isObject(input))
        return input;
    throw new Error(`toJSON/error: invalid type '${getType.default(input)}'`);
};

exports.default = toJSON;
