'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fs = require('fs');
var archiver = require('archiver');
var kleur = require('kleur');
var trimEnd = require('./trimEnd-BzcVuRxk.js');
var _baseTrim = require('./_baseTrim-DcCJukrn.js');
var echo = require('./echo.js');
var getBasename = require('./getBasename.js');
var getDirname = require('./getDirname.js');
var glob = require('./glob.js');
var normalizePath = require('./normalizePath.js');
var toArray$1 = require('./toArray.js');
var toString$1 = require('./toString.js');
var wrapList = require('./wrapList.js');
require('./home.js');
require('os');
require('./root.js');
require('./getType.js');
require('./getName.js');
require('path');
require('fast-glob');

var baseIndexOf = trimEnd._baseIndexOf;

/**
 * Used by `_.trim` and `_.trimStart` to get the index of the first string symbol
 * that is not found in the character symbols.
 *
 * @private
 * @param {Array} strSymbols The string symbols to inspect.
 * @param {Array} chrSymbols The character symbols to find.
 * @returns {number} Returns the index of the first unmatched string symbol.
 */
function charsStartIndex$1(strSymbols, chrSymbols) {
  var index = -1,
      length = strSymbols.length;

  while (++index < length && baseIndexOf(chrSymbols, strSymbols[index], 0) > -1) {}
  return index;
}

var _charsStartIndex = charsStartIndex$1;

var baseToString = trimEnd._baseToString,
    baseTrim = _baseTrim._baseTrim,
    castSlice = trimEnd._castSlice,
    charsEndIndex = trimEnd._charsEndIndex,
    charsStartIndex = _charsStartIndex,
    stringToArray = trimEnd._stringToArray,
    toString = trimEnd.toString_1;

/**
 * Removes leading and trailing whitespace or specified characters from `string`.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category String
 * @param {string} [string=''] The string to trim.
 * @param {string} [chars=whitespace] The characters to trim.
 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
 * @returns {string} Returns the trimmed string.
 * @example
 *
 * _.trim('  abc  ');
 * // => 'abc'
 *
 * _.trim('-_-abc-_-', '_-');
 * // => 'abc'
 *
 * _.map(['  foo  ', '  bar  '], _.trim);
 * // => ['foo', 'bar']
 */
function trim(string, chars, guard) {
  string = toString(string);
  if (string && (guard || chars === undefined)) {
    return baseTrim(string);
  }
  if (!string || !(chars = baseToString(chars))) {
    return string;
  }
  var strSymbols = stringToArray(string),
      chrSymbols = stringToArray(chars),
      start = charsStartIndex(strSymbols, chrSymbols),
      end = charsEndIndex(strSymbols, chrSymbols) + 1;

  return castSlice(strSymbols, start, end).join('');
}

var trim_1 = trim;

var trim$1 = /*@__PURE__*/trimEnd.getDefaultExportFromCjs(trim_1);

// function
const execute = async (listSource, target, options) => {
    const { base, filename } = options;
    const listResource = await glob.default(listSource);
    await new Promise(resolve => {
        const output = fs.createWriteStream(`${target}/${filename}`);
        const archive = archiver('zip', {
            zlib: {
                level: 9,
            },
        });
        let message = '';
        archive.on('end', () => resolve(true));
        archive.on('entry', e => (message = echo.renderPath(e.name)));
        archive.on('error', e => {
            console.log(kleur.red(e.message));
            throw e;
        });
        archive.on('progress', e => {
            if (!message)
                return;
            const gray = kleur.gray(`${Math.round((e.fs.processedBytes * 100) / e.fs.totalBytes)}%`);
            const magenta = kleur.magenta(message);
            console.log(`${gray} ${magenta}`);
            message = '';
        });
        archive.on('warning', e => {
            console.log(kleur.red(e.message));
            throw e;
        });
        // execute
        archive.pipe(output);
        for (const src of listResource) {
            const name = src.replace(base, '');
            archive.file(src, { name });
        }
        archive.finalize();
    });
};
const toArray = (source, target, option) => {
    const listSource = toArray$1.default(source).map(normalizePath.default);
    const pathTarget = normalizePath.default(target || getDirname.default(listSource[0]).replace(/\*/g, ''));
    let [base, filename] = typeof option === 'string'
        ? ['', option]
        : [option.base ?? '', option.filename ?? ''];
    base = normalizePath.default(base || getBase(listSource));
    if (!filename)
        filename = `${getBasename.default(pathTarget)}.zip`;
    return [
        listSource,
        pathTarget,
        {
            base,
            filename,
        },
    ];
};
const getBase = (listSource) => {
    const [source] = listSource;
    if (source.includes('*'))
        return trim$1(source.replace(/\*.*/u, ''), '/');
    return getDirname.default(source);
};
/**
 * Zip the source to the target.
 * @param source The source file or directory.
 * @param target The target directory.
 * @param option The option.
 * @example
 * ```
 * zip('src', 'dist', 'archive.zip')
 * zip('src', 'dist', { base: 'src', filename: 'archive.zip' })
 * zip(['src', 'public'], 'dist', 'archive.zip')
 * zip(['src', 'public'], 'dist', { base: 'src', filename: 'archive.zip' })
 * ```
 */
const zip = async (source, target = '', option = '') => {
    await execute(...toArray(source, target, option));
    echo.default('zip', `zipped ${wrapList.default(source)} to '${target}', as '${toString$1.default(option)}'`);
};

exports.default = zip;
